==> cejs-4.5.1.tgz: package/application/locale/resources/tyv-RU.js <==
/*	Localized messages of CeL.
	This file is auto created by auto-generate tool: build.nodejs(.js) @ 2022.
*/'use strict';typeof CeL==='function'&&CeL.application.locale.gettext.set_text({
	"Loading...": "\u0427\u04af\u0434\u04af\u0440\u04af\u0433...",
	"Loading %1%...": "\u0427\u04af\u0434\u04af\u0440\u0435\u0440\u0438 %1%...",
	"debug level": "\u044d\u043f\u0442\u044d\u044d\u0448\u043a\u0438\u043d \u0434\u0435\u04a3\u043d\u0435\u043b\u0438",
	"log-type-info": "\u0438\u043d\u0444\u043e",
	"Language": "\u0414\u044b\u043b",
	"no change": "\u04e9\u0441\u043a\u0435\u0440\u043b\u0438\u0438\u0448\u043a\u0438\u043d \u0447\u043e\u043a",
	"finished: %1": "\u0434\u043e\u043e\u0437\u0443\u043b\u0433\u0430\u043d: %1",
	"Content is not settled": "\u041a\u043e\u043d\u0442\u0435\u043d\u0442\u0438\u043d\u0438 \u0434\u0443\u0433\u0443\u0440\u0443\u0448\u043f\u0430\u0430\u043d",
	"%1 ms": "%1 \u043c\u0441",
	"%1 s": "%1 \u0441",
	"soon": "\u0443\u0434\u0430\u0432\u0430\u0441",
	"%1 seconds later": "%1 \u0441\u0435\u043a\u0443\u043d\u0434\u0430 \u0431\u043e\u043b\u0433\u0430\u0448",
	"%1 hours later": "%1 \u0448\u0430\u043a \u0431\u043e\u043b\u0433\u0430\u0448",
	"today, %H:%M": "\u0431\u043e \u0445\u04af\u043d, %H:%M",
	"the day after tomorrow, %H:%M": "\u044d\u0440\u0442\u0435\u043d\u0433\u0438 \u0445\u04af\u043d \u0441\u043e\u043e\u043d\u0434\u0430 \u0445\u04af\u043d, %H:%M",
	"2 days after tomorrow, %H:%M": "\u042d\u0440\u0442\u0435\u043d\u0433\u0438 \u0445\u04af\u043d \u0441\u043e\u043e\u043d\u0434\u0430 2 \u0445\u04af\u043d, %H:%M",
	"%1 days ago": "%1 \u0445\u04af\u043d \u0431\u0443\u0440\u0443\u043d\u0433\u0430\u0430\u0440",
	"\u7d00\u5e74\u8f49\u63db\u5de5\u5177": "\u042d\u0440\u0430 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440 \u043a\u043e\u043d\u0432\u0435\u0440\u0442\u0435\u0440\u0438",
	"\u7d00\u5e74 %1": "\u042d\u0440\u0430 %1",
	"\u4e2d\u570b": "\u041a\u044b\u0434\u0430\u0442",
	"\u65e5\u672c": "\u042f\u043f\u043e\u043d\u0438\u044f",
	"Maya": "\u041c\u0430\u0439\u0430",
	"Mesopotamian": "\u041c\u0435\u0441\u043e\u043f\u043e\u0442\u0430\u043c",
	"Babylon": "\u0412\u0430\u0432\u0438\u043b\u043e\u043d",
	"Neo-Assyrian": "\u0427\u0430\u0430 \u0410\u0441\u0441\u0438\u0440\u0438\u0439",
	"\u03a3\u03c0\u03ac\u03c1\u03c4\u03b7": "\u0421\u043f\u0430\u0440\u0442\u0430",
	"\u7d00\u5e74": "\u042d\u0440\u0430 \u0430\u0434\u044b",
	"\u6e2c\u8a66\u7bc4\u4f8b": "\u0427\u0418\u0416\u0415\u041a",
	"\u8a2d\u5b9a": "\u041a\u041e\u041d\u0424\u0418\u0413\u0423\u0420\u0410\u0421",
	"\u63a1\u7528\u66c6\u6cd5": "\u041a\u0430\u043b\u0435\u043d\u0434\u0430\u0440 \u0430\u0436\u044b\u0433\u043b\u0430\u0442\u0442\u044b\u043d\u0433\u0430\u043d",
	"\u541b\u4e3b\u865f": "\u0423\u0440\u0430\u043d \u0447\u04af\u04af\u043b \u0430\u0434\u044b",
	"\u8af1": "\u0428\u044b\u043d \u0430\u0434\u044b",
	"\u8ae1": "\u041c\u04e9\u0447\u044d\u044d\u043d \u0441\u043e\u043e\u043d\u0434\u0430 \u0430\u0434\u044b",
	"\u901d\u4e16": "\u041c\u04e9\u0447\u044d\u044d\u043d\u0438",
	"\u52a0\u5195": "\u041a\u043e\u0440\u043e\u043d\u0430\u0441",
	"\u7236\u89aa": "\u0410\u0434\u0430",
	"\u6bcd\u89aa": "\u0418\u0435",
	"\u524d\u4efb": "\u041c\u0443\u0440\u043d\u0443\u043d\u0434\u0430\u0433\u044b\u0437\u044b",
	"\u7e7c\u4efb": "\u0421\u0430\u043b\u0433\u0430\u043a\u0447\u044b\u0437\u044b",
	"\u5206\u985e": "\u0411\u04e9\u043b\u04af\u043a",
	"Gregorian calendar": "\u0413\u0440\u0435\u0433\u043e\u0440\u0438\u0430\u043d \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"Julian Day Number": "\u042e\u043b\u0438\u0430\u043d \u0445\u04af\u043d \u0434\u0443\u0433\u0430\u0430\u0440\u044b",
	"astronomy": "\u0430\u0441\u0442\u0440\u043e\u043d\u043e\u043c\u0438\u044f",
	"Year naming": "\u0427\u044b\u043b \u0430\u0434\u0430\u0430\u0440\u044b",
	"Gregorian reform": "\u0413\u0440\u0435\u0433\u043e\u0440\u0438\u0430\u043d \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440 \u0445\u04af\u043b\u044d\u044d\u0448\u043a\u0438\u043d\u0438",
	"Holocene calendar": "\u0413\u043e\u043b\u043e\u0441\u0435\u043d \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"lunar eclipse": "\u0430\u0439 \u0442\u0443\u0442\u0442\u0443\u0440\u0443\u0443\u0448\u043a\u0443\u043d\u0443",
	"hybrid solar eclipse": "\u0433\u0438\u0431\u0440\u0438\u0434 \u0445\u04af\u043d \u0442\u0443\u0442\u0442\u0443\u0440\u0443\u0443\u0448\u043a\u0443\u043d\u0443",
	"partial solar eclipse": "\u0434\u043e\u043b\u0443 \u044d\u0432\u0435\u0441 \u0445\u04af\u043d \u0442\u0443\u0442\u0442\u0443\u0440\u0443\u0443\u0448\u043a\u0443\u043d\u0443",
	"\u6714": "\u0447\u0430\u0430 \u0430\u0439",
	"\u671b": "\u0434\u043e\u043b\u0443 \u0430\u0439",
	"\u65e5\u51fa\u65e5\u843d": "\u0445\u04af\u043d \u04af\u043d\u0435\u0440\u0438 / \u0445\u04af\u043d \u0430\u0436\u0430\u0440\u044b",
	"nautical twilight end": "\u0434\u0430\u043b\u0430\u0439 \u0438\u043c\u0438\u0440 \u0442\u04e9\u043d\u0447\u04af\u0437\u04af",
	"Revised Julian calendar": "\u042d\u0434\u0435 \u043a\u04e9\u0440\u0434\u04af\u043d\u0433\u0435\u043d \u042e\u043b\u0438\u0430\u043d \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"\u4f0a\u65af\u862d\u66c6": "\u0418\u0441\u043b\u0430\u043c \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"\u06af\u0627\u0647\u200c\u0634\u0645\u0627\u0631\u06cc \u0647\u062c\u0631\u06cc \u062e\u0648\u0631\u0634\u06cc\u062f\u06cc": "\u0410\u043c\u0433\u044b \u0448\u0430\u0433\u043d\u044b\u04a3 \u0418\u0440\u0430\u043d \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u044b",
	"\u9577\u7d00\u66c6": "\u0423\u0437\u0443\u043d \u0441\u0430\u043d\u0430\u0430\u0448\u043a\u044b\u043d",
	"\u0939\u093f\u0928\u094d\u0926\u0942 \u092a\u0902\u091a\u093e\u0902\u0917": "\u0418\u043d\u0434\u0438\u0439 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"\u06af\u0627\u0647\u200c\u0634\u0645\u0627\u0631\u06cc \u0628\u0647\u0627\u0626\u06cc": "\u0411\u0430\u0445\u0430\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"\u79d1\u666e\u7279\u66c6": "\u041a\u043e\u043f\u0442 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"\u8863\u7d22\u6bd4\u4e9e\u66c6": "\u042d\u0444\u0438\u043e\u043f \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"Byzantine calendar": "\u0412\u0438\u0437\u0430\u043d\u0442\u0438\u0439 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"Calendrier r\u00e9publicain": "\u0424\u0440\u0430\u043d\u0446\u0443\u0437 \u0420\u0435\u0441\u043f\u0443\u0431\u043b\u0438\u043a\u0430\u043d \u041a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"Taurus": "\u0411\u0443\u0433\u0430",
	"Gemini": "\u0418\u0439\u0438\u0441",
	"Leo": "\u041b\u0435\u043e",
	"Virgo": "\u041a\u044b\u0441",
	"Pisces": "\u0411\u0430\u043b\u044b\u043a",
	"\u751f\u8096": "\u041a\u044b\u0434\u0430\u0442 \u0437\u043e\u0434\u0438\u0430\u043a",
	"\u7687\u7d00": "\u042f\u043f\u043e\u043d \u0438\u043c\u043f\u0435\u0440\u0438\u0430\u043b \u0447\u044b\u043b",
	"\u7f85\u99ac\u5efa\u57ce": "\u0425\u043e\u043e\u0440\u0430\u0439",
	"Luxembourg": "\u041b\u044e\u043a\u0441\u0435\u043c\u0431\u0443\u0440\u0433",
	"Netherlands": "\u041d\u0435\u0434\u0435\u0440\u043b\u0430\u043d\u0434",
	"Bavaria": "\u0411\u0430\u0432\u0430\u0440\u0438\u0430",
	"Austria": "\u0410\u0432\u0441\u0442\u0440\u0438\u044f",
	"Hungary": "\u0412\u0435\u043d\u0433\u0440\u0438\u044f",
	"Norway": "\u041d\u043e\u0440\u0432\u0435\u0433\u0438\u044f",
	"Denmark": "\u0414\u0430\u043d\u0438",
	"Great Britain": "\u0423\u043b\u0443\u0433 \u0411\u0440\u0438\u0442\u0430\u043d\u0438\u044f",
	"\u540c\u570b\u5171\u5b58\u7d00\u5e74": "\u0410\u043c\u0433\u044b \u0448\u0430\u0433 (\u043e\u043b-\u043b\u0430 \u0447\u0443\u0440\u0442)",
	"\u5c0e\u89bd\u5217\uff1a": "\u041d\u0430\u0432\u0438\u0433\u0430\u0441:",
	"\u8cc7\u6599\u5716\u5c64": "\u041c\u0435\u0434\u044d\u044d\u043b\u0435\u043b \u043a\u0430\u044a\u0434\u044b",
	"untranslated message count": "967"
},
"tyv-RU");

==> cejs-4.5.2.tgz: package/application/locale/resources/tyv-RU.js <==
/*	Localized messages of CeL.
	This file is auto created by auto-generate tool: build.nodejs(.js) @ 2022.
*/'use strict';typeof CeL==='function'&&CeL.application.locale.gettext.set_text({
	"untranslated message count": "1000+",
	"Calendrier r\u00e9publicain": "\u0424\u0440\u0430\u043d\u0446\u0443\u0437 \u0420\u0435\u0441\u043f\u0443\u0431\u043b\u0438\u043a\u0430\u043d \u041a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"\u7d00\u5e74\u8f49\u63db\u5de5\u5177": "\u042d\u0440\u0430 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440 \u043a\u043e\u043d\u0432\u0435\u0440\u0442\u0435\u0440\u0438",
	"Loading...": "\u0427\u04af\u0434\u04af\u0440\u04af\u0433...",
	"\u8cc7\u6599\u5716\u5c64": "\u041c\u0435\u0434\u044d\u044d\u043b\u0435\u043b \u043a\u0430\u044a\u0434\u044b",
	"\u5c0e\u89bd\u5217\uff1a": "\u041d\u0430\u0432\u0438\u0433\u0430\u0441:",
	"\u6e2c\u8a66\u7bc4\u4f8b": "\u0427\u0418\u0416\u0415\u041a",
	"\u8a2d\u5b9a": "\u041a\u041e\u041d\u0424\u0418\u0413\u0423\u0420\u0410\u0421",
	"Julian Day Number": "\u042e\u043b\u0438\u0430\u043d \u0445\u04af\u043d \u0434\u0443\u0433\u0430\u0430\u0440\u044b",
	"Great Britain": "\u0423\u043b\u0443\u0433 \u0411\u0440\u0438\u0442\u0430\u043d\u0438\u044f",
	"\u63a1\u7528\u66c6\u6cd5": "\u041a\u0430\u043b\u0435\u043d\u0434\u0430\u0440 \u0430\u0436\u044b\u0433\u043b\u0430\u0442\u0442\u044b\u043d\u0433\u0430\u043d",
	"\u541b\u4e3b\u865f": "\u0423\u0440\u0430\u043d \u0447\u04af\u04af\u043b \u0430\u0434\u044b",
	"\u8af1": "\u0428\u044b\u043d \u0430\u0434\u044b",
	"\u8ae1": "\u041c\u04e9\u0447\u044d\u044d\u043d \u0441\u043e\u043e\u043d\u0434\u0430 \u0430\u0434\u044b",
	"\u901d\u4e16": "\u041c\u04e9\u0447\u044d\u044d\u043d\u0438",
	"\u52a0\u5195": "\u041a\u043e\u0440\u043e\u043d\u0430\u0441",
	"\u524d\u4efb": "\u041c\u0443\u0440\u043d\u0443\u043d\u0434\u0430\u0433\u044b\u0437\u044b",
	"\u7e7c\u4efb": "\u0421\u0430\u043b\u0433\u0430\u043a\u0447\u044b\u0437\u044b",
	"\u7236\u89aa": "\u0410\u0434\u0430",
	"\u6bcd\u89aa": "\u0418\u0435",
	"\u7d00\u5e74 %1": "\u042d\u0440\u0430 %1",
	"Taurus": "\u0411\u0443\u0433\u0430",
	"Gemini": "\u0418\u0439\u0438\u0441",
	"Leo": "\u041b\u0435\u043e",
	"Virgo": "\u041a\u044b\u0441",
	"Pisces": "\u0411\u0430\u043b\u044b\u043a",
	"\u540c\u570b\u5171\u5b58\u7d00\u5e74": "\u0410\u043c\u0433\u044b \u0448\u0430\u0433 (\u043e\u043b-\u043b\u0430 \u0447\u0443\u0440\u0442)",
	"\u6714": "\u0447\u0430\u0430 \u0430\u0439",
	"\u65e5\u51fa\u65e5\u843d": "\u0445\u04af\u043d \u04af\u043d\u0435\u0440\u0438 / \u0445\u04af\u043d \u0430\u0436\u0430\u0440\u044b",
	"Gregorian calendar": "\u0413\u0440\u0435\u0433\u043e\u0440\u0438\u0430\u043d \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"Revised Julian calendar": "\u042d\u0434\u0435 \u043a\u04e9\u0440\u0434\u04af\u043d\u0433\u0435\u043d \u042e\u043b\u0438\u0430\u043d \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"\u4f0a\u65af\u862d\u66c6": "\u0418\u0441\u043b\u0430\u043c \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"\u06af\u0627\u0647\u200c\u0634\u0645\u0627\u0631\u06cc \u0647\u062c\u0631\u06cc \u062e\u0648\u0631\u0634\u06cc\u062f\u06cc": "\u0410\u043c\u0433\u044b \u0448\u0430\u0433\u043d\u044b\u04a3 \u0418\u0440\u0430\u043d \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u044b",
	"\u9577\u7d00\u66c6": "\u0423\u0437\u0443\u043d \u0441\u0430\u043d\u0430\u0430\u0448\u043a\u044b\u043d",
	"\u5206\u985e": "\u0411\u04e9\u043b\u04af\u043a",
	"\u0939\u093f\u0928\u094d\u0926\u0942 \u092a\u0902\u091a\u093e\u0902\u0917": "\u0418\u043d\u0434\u0438\u0439 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"\u06af\u0627\u0647\u200c\u0634\u0645\u0627\u0631\u06cc \u0628\u0647\u0627\u0626\u06cc": "\u0411\u0430\u0445\u0430\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"\u79d1\u666e\u7279\u66c6": "\u041a\u043e\u043f\u0442 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"\u8863\u7d22\u6bd4\u4e9e\u66c6": "\u042d\u0444\u0438\u043e\u043f \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"Byzantine calendar": "\u0412\u0438\u0437\u0430\u043d\u0442\u0438\u0439 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"\u4e2d\u570b": "\u041a\u044b\u0434\u0430\u0442",
	"Year naming": "\u0427\u044b\u043b \u0430\u0434\u0430\u0430\u0440\u044b",
	"\u751f\u8096": "\u041a\u044b\u0434\u0430\u0442 \u0437\u043e\u0434\u0438\u0430\u043a",
	"\u7687\u7d00": "\u042f\u043f\u043e\u043d \u0438\u043c\u043f\u0435\u0440\u0438\u0430\u043b \u0447\u044b\u043b",
	"\u7f85\u99ac\u5efa\u57ce": "\u0425\u043e\u043e\u0440\u0430\u0439",
	"Holocene calendar": "\u0413\u043e\u043b\u043e\u0441\u0435\u043d \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440",
	"Gregorian reform": "\u0413\u0440\u0435\u0433\u043e\u0440\u0438\u0430\u043d \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440 \u0445\u04af\u043b\u044d\u044d\u0448\u043a\u0438\u043d\u0438",
	"astronomy": "\u0430\u0441\u0442\u0440\u043e\u043d\u043e\u043c\u0438\u044f",
	"Loading %1%...": "\u0427\u04af\u0434\u04af\u0440\u0435\u0440\u0438 %1%...",
	"\u671b": "\u0434\u043e\u043b\u0443 \u0430\u0439",
	"hybrid solar eclipse": "\u0433\u0438\u0431\u0440\u0438\u0434 \u0445\u04af\u043d \u0442\u0443\u0442\u0442\u0443\u0440\u0443\u0443\u0448\u043a\u0443\u043d\u0443",
	"partial solar eclipse": "\u0434\u043e\u043b\u0443 \u044d\u0432\u0435\u0441 \u0445\u04af\u043d \u0442\u0443\u0442\u0442\u0443\u0440\u0443\u0443\u0448\u043a\u0443\u043d\u0443",
	"lunar eclipse": "\u0430\u0439 \u0442\u0443\u0442\u0442\u0443\u0440\u0443\u0443\u0448\u043a\u0443\u043d\u0443",
	"nautical twilight end": "\u0434\u0430\u043b\u0430\u0439 \u0438\u043c\u0438\u0440 \u0442\u04e9\u043d\u0447\u04af\u0437\u04af",
	"log-type-info": "\u0438\u043d\u0444\u043e",
	"Language": "\u0414\u044b\u043b",
	"Content is not settled": "\u041a\u043e\u043d\u0442\u0435\u043d\u0442\u0438\u043d\u0438 \u0434\u0443\u0433\u0443\u0440\u0443\u0448\u043f\u0430\u0430\u043d",
	"no change": "\u04e9\u0441\u043a\u0435\u0440\u043b\u0438\u0438\u0448\u043a\u0438\u043d \u0447\u043e\u043a",
	"finished: %1": "\u0434\u043e\u043e\u0437\u0443\u043b\u0433\u0430\u043d: %1",
	"Luxembourg": "\u041b\u044e\u043a\u0441\u0435\u043c\u0431\u0443\u0440\u0433",
	"Netherlands": "\u041d\u0435\u0434\u0435\u0440\u043b\u0430\u043d\u0434",
	"Bavaria": "\u0411\u0430\u0432\u0430\u0440\u0438\u0430",
	"Austria": "\u0410\u0432\u0441\u0442\u0440\u0438\u044f",
	"Hungary": "\u0412\u0435\u043d\u0433\u0440\u0438\u044f",
	"Norway": "\u041d\u043e\u0440\u0432\u0435\u0433\u0438\u044f",
	"Denmark": "\u0414\u0430\u043d\u0438",
	"%1 ms": "%1 \u043c\u0441",
	"%1 s": "%1 \u0441",
	"today, %H:%M": "\u0431\u043e \u0445\u04af\u043d, %H:%M",
	"the day after tomorrow, %H:%M": "\u044d\u0440\u0442\u0435\u043d\u0433\u0438 \u0445\u04af\u043d \u0441\u043e\u043e\u043d\u0434\u0430 \u0445\u04af\u043d, %H:%M",
	"2 days after tomorrow, %H:%M": "\u042d\u0440\u0442\u0435\u043d\u0433\u0438 \u0445\u04af\u043d \u0441\u043e\u043e\u043d\u0434\u0430 2 \u0445\u04af\u043d, %H:%M",
	"soon": "\u0443\u0434\u0430\u0432\u0430\u0441",
	"%1 {{PLURAL:%1|second|seconds}} later": "%1 \u0441\u0435\u043a\u0443\u043d\u0434\u0430 \u0431\u043e\u043b\u0433\u0430\u0448",
	"%1 {{PLURAL:%1|hour|hours}} later": "%1 \u0448\u0430\u043a \u0431\u043e\u043b\u0433\u0430\u0448",
	"%1 {{PLURAL:%1|day|days}} ago": "%1 \u0445\u04af\u043d \u0431\u0443\u0440\u0443\u043d\u0433\u0430\u0430\u0440",
	"\u7d00\u5e74": "\u042d\u0440\u0430 \u0430\u0434\u044b",
	"\u65e5\u672c": "\u042f\u043f\u043e\u043d\u0438\u044f",
	"Mesopotamian": "\u041c\u0435\u0441\u043e\u043f\u043e\u0442\u0430\u043c",
	"Neo-Assyrian": "\u0427\u0430\u0430 \u0410\u0441\u0441\u0438\u0440\u0438\u0439",
	"Babylon": "\u0412\u0430\u0432\u0438\u043b\u043e\u043d",
	"\u03a3\u03c0\u03ac\u03c1\u03c4\u03b7": "\u0421\u043f\u0430\u0440\u0442\u0430",
	"Maya": "\u041c\u0430\u0439\u0430",
	"debug level": "\u044d\u043f\u0442\u044d\u044d\u0448\u043a\u0438\u043d \u0434\u0435\u04a3\u043d\u0435\u043b\u0438"
},
"tyv-RU");
